@@ -9,9 +9,6 @@ class Entity(models.Model):
         null=True,
         verbose_name=_('Client Session'),
     )
-    entity_id = models.BigIntegerField(
-        verbose_name=_('Entity ID'),
-    )
     hash_value = models.BigIntegerField(
         blank=False,
         null=False,
@@ -30,7 +27,7 @@ class Entity(models.Model):
         verbose_name=_('Phone'),
     )
     name = models.CharField(
-        max_length=150,
+        max_length=50,
         blank=True,
         null=True,
         verbose_name=_('Name'),
